#version 130

uniform sampler2D highresImageSampler2D;
uniform sampler2D lowresImageSampler2D;
uniform int kernelSize;

void main() {
	
	ivec2 texCoord = ivec2((textureSize(highresImageSampler2D,0) - ivec2(1) - ivec2(gl_FragCoord.xy)));

	vec4 centerImgval = texelFetch(highresImageSampler2D, texCoord, 0);

	vec4 sum = vec4(0);
	float weightSum = 0;
	for(int i = -kernelSize; i <= kernelSize; i++) {
		for(int j = -kernelSize; j <= kernelSize; j++) {

			float spatialDistance = sqrt(float(i * i) + float(j * j));
			
			vec4 highresImgval = texelFetch(highresImageSampler2D, texCoord + ivec2(i, j), 0);
			float rangeDistance = length(highresImgval - centerImgval);
			
			float SIGMA = kernelSize / 2;
			float SIGMA_INTENSITY = 0.1;
			float weight = 
				exp(-(spatialDistance * spatialDistance) / (2.0 * SIGMA * SIGMA)) * 
				exp(-(rangeDistance * rangeDistance) / (2 * SIGMA_INTENSITY * SIGMA_INTENSITY));
	
			weightSum += weight;

			vec4 lowresImgval = texelFetch(lowresImageSampler2D, ivec2((texCoord + ivec2(i, j)) / 8 + ivec2(0, 0)), 0);

			sum += weight * lowresImgval;
		}
	}

	gl_FragColor = sum / vec4(weightSum);
}
